@@ -8,7 +8,8 @@ var TableSelectAll = function TableSelectAll(_ref) {
       id = _ref.id,
       indeterminate = _ref.indeterminate,
       name = _ref.name,
-      onSelect = _ref.onSelect;
+      onSelect = _ref.onSelect,
+      disabled = _ref.disabled;
   return React.createElement("th", {
     scope: "col"
   }, React.createElement(InlineCheckbox, {
@@ -17,7 +18,8 @@ var TableSelectAll = function TableSelectAll(_ref) {
     id: id,
     indeterminate: indeterminate,
     name: name,
-    onClick: onSelect
+    onClick: onSelect,
+    disabled: disabled
   }));
 };
 
