@@ -1,7 +1,9 @@
 import wrapComponent from '../../tools/wrapComponent';
+import { settings } from 'carbon-components';
+var prefix = settings.prefix;
 var TableToolbarContent = wrapComponent({
   name: 'TableToolbarContent',
   type: 'div',
-  className: ['bx--toolbar-content']
+  className: "".concat(prefix, "--toolbar-content")
 });
 export default TableToolbarContent;
\ No newline at end of file
