@@ -1,9 +1,8 @@
-var _curry2 = /*#__PURE__*/require('./internal/_curry2');
+var _curry2 = require('./internal/_curry2');
 
 /**
  * Takes a list and returns a list of lists where each sublist's elements are
- * all satisfied pairwise comparison according to the provided function.
- * Only adjacent elements are passed to the comparison function.
+ * all "equal" according to the provided equality function.
  *
  * @func
  * @memberOf R
@@ -14,31 +13,26 @@ var _curry2 = /*#__PURE__*/require('./internal/_curry2');
  *        elements should be in the same group
  * @param {Array} list The array to group. Also accepts a string, which will be
  *        treated as a list of characters.
- * @return {List} A list that contains sublists of elements,
+ * @return {List} A list that contains sublists of equal elements,
  *         whose concatenations are equal to the original list.
  * @example
  *
  * R.groupWith(R.equals, [0, 1, 1, 2, 3, 5, 8, 13, 21])
  * //=> [[0], [1, 1], [2], [3], [5], [8], [13], [21]]
  *
- * R.groupWith((a, b) => a + 1 === b, [0, 1, 1, 2, 3, 5, 8, 13, 21])
- * //=> [[0, 1], [1, 2, 3], [5], [8], [13], [21]]
- *
  * R.groupWith((a, b) => a % 2 === b % 2, [0, 1, 1, 2, 3, 5, 8, 13, 21])
  * //=> [[0], [1, 1], [2], [3, 5], [8], [13, 21]]
  *
  * R.groupWith(R.eqBy(isVowel), 'aestiou')
  * //=> ['ae', 'st', 'iou']
  */
-
-
-var groupWith = /*#__PURE__*/_curry2(function (fn, list) {
+module.exports = _curry2(function(fn, list) {
   var res = [];
   var idx = 0;
   var len = list.length;
   while (idx < len) {
     var nextidx = idx + 1;
-    while (nextidx < len && fn(list[nextidx - 1], list[nextidx])) {
+    while (nextidx < len && fn(list[idx], list[nextidx])) {
       nextidx += 1;
     }
     res.push(list.slice(idx, nextidx));
@@ -46,4 +40,3 @@ var groupWith = /*#__PURE__*/_curry2(function (fn, list) {
   }
   return res;
 });
-module.exports = groupWith;
\ No newline at end of file
